# ContentfulApp MCP Server

An MCP Server for the ContentfulApp API.

## 🛠️ Tool List

This is automatically generated from OpenAPI schema for the ContentfulApp API.


| Tool | Description |
|------|-------------|
| `get_entry` | Fetches a single entry of a specified content type by its ID. |
| `get_entries_collection` | Fetches a collection of entries of a specified content type. |
| `get_asset` | Fetches a single asset by its ID. |
| `get_assets_collection` | Fetches a collection of assets. |
| `execute_graphql_query` | Executes an arbitrary GraphQL query. |
| `execute_graphql_mutation` | Executes an arbitrary GraphQL mutation. |
